import unittest
from ExtendedDiagramIcons.module2 import ok

class TestCase(unittest.TestCase):
    def test_ok(self):
        print(ok())

if __name__ == "__main__":
    unittest.main()
    print(Test.assetEqual)