from ...common import CustomNode

class octopusDeployProgram(CustomNode):
    _icon = "octopus_deploy_icon.png"

class octopusDeployPipeline(CustomNode):
    _icon = "pipeline_icon.png"

class octopusDeployServerNode(CustomNode):
    _icon = "octopus_server_node_icon.png"

class octopusDeployWorkerNode(CustomNode):
    _icon = "octopus_worker_node_icon.png"

class octopusDeployWorkerPool(CustomNode):
    _icon = "octopus_worker_pool_icon.png"

class octpusDeployRelease(CustomNode):
    _icon = "release_icon.png"