from .common import CustomNode

class softwareEngineer(CustomNode):
    _icon = "software_engineer_icon.png"

class JIRA(CustomNode):
    _icon = "jira_icon.png"

class GitHub(CustomNode):
    _icon = "github_icon.png"

class CRIMTools(CustomNode):
    _icon = "crim_tools_icon.png"

class ReportPortal(CustomNode):
    _icon = "report_portal_icon.jpg"